==> keycloak-model-map-hot-rod-20.0.2-sources.jar: org/keycloak/models/map/storage/hotRod/events/HotRodAdminEventEntityDescriptor.java <==
package org.keycloak.models.map.storage.hotRod.events;
import org.infinispan.protostream.GeneratedSchema;
import java.util.function.Function;
public class HotRodAdminEventEntityDescriptor implements org.keycloak.models.map.storage.hotRod.common.HotRodEntityDescriptor<org.keycloak.models.map.storage.hotRod.events.HotRodAdminEventEntity, org.keycloak.models.map.storage.hotRod.events.HotRodAdminEventEntityDelegate> {
    @Override
    public Class<?> getModelTypeClass() {
        return org.keycloak.events.admin.AdminEvent.class;
    }
    @Override
    public Class<org.keycloak.models.map.storage.hotRod.events.HotRodAdminEventEntity> getEntityTypeClass() {
        return org.keycloak.models.map.storage.hotRod.events.HotRodAdminEventEntity.class;
    }
    @Override
    public String getCacheName() {
        return org.keycloak.models.map.storage.ModelEntityUtil.getModelName(org.keycloak.events.admin.AdminEvent.class);
    }
    @Override
    public Function<org.keycloak.models.map.storage.hotRod.events.HotRodAdminEventEntity, org.keycloak.models.map.storage.hotRod.events.HotRodAdminEventEntityDelegate> getHotRodDelegateProvider() {
        return org.keycloak.models.map.storage.hotRod.events.HotRodAdminEventEntityDelegate::new;
    }
    @Override
    public Integer getCurrentVersion() {
        return org.keycloak.models.map.storage.hotRod.events.HotRodAdminEventEntity.VERSION;
    }
    @Override
    public GeneratedSchema getProtoSchema() {
        return org.keycloak.models.map.storage.hotRod.events.HotRodAdminEventEntity.HotRodAdminEventEntitySchema.INSTANCE;
    }
}

==> keycloak-model-map-hot-rod-22.0.5-sources.jar: org/keycloak/models/map/storage/hotRod/events/HotRodAdminEventEntityDescriptor.java <==
package org.keycloak.models.map.storage.hotRod.events;
import org.infinispan.protostream.GeneratedSchema;
import java.util.function.Function;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateHotRodEntityImplementationsProcessor")
public class HotRodAdminEventEntityDescriptor implements org.keycloak.models.map.storage.hotRod.common.HotRodEntityDescriptor<org.keycloak.models.map.storage.hotRod.events.HotRodAdminEventEntity, org.keycloak.models.map.storage.hotRod.events.HotRodAdminEventEntityDelegate> {
    @Override
    public Class<?> getModelTypeClass() {
        return org.keycloak.events.admin.AdminEvent.class;
    }
    @Override
    public Class<org.keycloak.models.map.storage.hotRod.events.HotRodAdminEventEntity> getEntityTypeClass() {
        return org.keycloak.models.map.storage.hotRod.events.HotRodAdminEventEntity.class;
    }
    @Override
    public String getCacheName() {
        return org.keycloak.models.map.storage.ModelEntityUtil.getModelName(org.keycloak.events.admin.AdminEvent.class);
    }
    @Override
    public Function<org.keycloak.models.map.storage.hotRod.events.HotRodAdminEventEntity, org.keycloak.models.map.storage.hotRod.events.HotRodAdminEventEntityDelegate> getHotRodDelegateProvider() {
        return org.keycloak.models.map.storage.hotRod.events.HotRodAdminEventEntityDelegate::new;
    }
    @Override
    public Integer getCurrentVersion() {
        return org.keycloak.models.map.storage.hotRod.events.HotRodAdminEventEntity.VERSION;
    }
    @Override
    public GeneratedSchema getProtoSchema() {
        return org.keycloak.models.map.storage.hotRod.events.HotRodAdminEventEntity.HotRodAdminEventEntitySchema.INSTANCE;
    }
}
